@@ -1,7 +1,7 @@
 package App::after;
 
-our $DATE = '2016-04-18'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-05-20'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -37,18 +37,15 @@ _
 
         delay => {
             schema => 'duration*',
-            'x.perl.coerce_to' => 'int(secs)',
             tags => ['category:condition'],
             cmdline_aliases => {d=>{}},
         },
         time => {
             schema => 'date*',
-            'x.perl.coerce_to' => 'int(epoch)',
             tags => ['category:condition'],
         },
         uptime => {
             schema => 'duration*',
-            'x.perl.coerce_to' => 'int(secs)',
             tags => ['category:condition'],
         },
         load_below => {
@@ -268,7 +265,7 @@ App::after - Run command after delay and/or other conditions
 
 =head1 VERSION
 
-This document describes version 0.02 of App::after (from Perl distribution App-after), released on 2016-04-18.
+This document describes version 0.03 of App::after (from Perl distribution App-after), released on 2016-05-20.
 
 =head1 DESCRIPTION
 
